summaryrefslogtreecommitdiffstats
path: root/components/offline_pages/proto
diff options
context:
space:
mode:
authorfgorski <fgorski@chromium.org>2015-08-06 14:43:48 -0700
committerCommit bot <commit-bot@chromium.org>2015-08-06 21:44:29 +0000
commitab60e095f549876f7d9bde834387f3da37316e70 (patch)
tree809192a6eeed46b1e7eb95a1734cc1f6940a2b04 /components/offline_pages/proto
parent4fb6b6f46c01262f37c7a170f3de2366f4d8cedf (diff)
downloadchromium_src-ab60e095f549876f7d9bde834387f3da37316e70.zip
chromium_src-ab60e095f549876f7d9bde834387f3da37316e70.tar.gz
chromium_src-ab60e095f549876f7d9bde834387f3da37316e70.tar.bz2
[Offline pages] Adding bookmark ID to offline page (removing title)
This change is necessary, as title is already stored by the bookmark, while bookmark ID is how all the filtering and matching is done by the model and UI. Without this update any filtering logic will be very inefficient. BUG=491352 Review URL: https://codereview.chromium.org/1262743006 Cr-Commit-Position: refs/heads/master@{#342206}
Diffstat (limited to 'components/offline_pages/proto')
-rw-r--r--components/offline_pages/proto/offline_pages.proto4
1 files changed, 2 insertions, 2 deletions
diff --git a/components/offline_pages/proto/offline_pages.proto b/components/offline_pages/proto/offline_pages.proto
index 16f23b1..07025a1 100644
--- a/components/offline_pages/proto/offline_pages.proto
+++ b/components/offline_pages/proto/offline_pages.proto
@@ -16,8 +16,8 @@ message OfflinePageEntry {
// URL of the offline page.
required string url = 1;
- // Title of the offline page.
- required string title = 2;
+ // Bookmark ID of the offline page.
+ required int64 bookmark_id = 2;
// Version of the offline page metadata.
required int32 version = 3;